@@ -2,12 +2,16 @@ if (interactive()) {
     library(dplyr)
 
     webFile <- readLines(con = "https://canvasxpress.org/data/cX-function.R")
-
+    
+    # fixes to URLs if required - these are known issues with the URLs in the test file
+    webFile <- gsub("https://www.canvasxpress.org/data/cX-olympicMedals",
+                    "https://www.canvasxpress.org/data/cX-OlympicMedals", webFile)
+    
     #grab url download links
     dataUrls <- data.frame(line = webFile, stringsAsFactors = F) %>%
         filter(grepl('read.table("https://www.canvasxpress.org', line,  fixed = TRUE)) %>%
         #exclude specific larger files
-        filter(!grepl('cX-codiv|LungCancinoma|visium', line)) %>% 
+        filter(!grepl('cX-codiv|LungCancinoma|visium|Olympic|exprtcga', line)) %>% 
         mutate(url = gsub('.*=read.table\\("', '', line),
                url = gsub('", .*', '', url)) %>%
         select(url) %>%
